@@ -9,12 +9,12 @@ our (@ISA, $VERSION, @EXPORT_OK, %EXPORT_TAGS);
 @ISA    = qw(IO::File Exporter);
 
 
-$VERSION = '2.086';
+$VERSION = '2.087';
 
 use constant G_EOF => 0 ;
 use constant G_ERR => -1 ;
 
-use IO::Compress::Base::Common 2.086 ;
+use IO::Compress::Base::Common 2.087 ;
 
 use IO::File ;
 use Symbol;
@@ -1010,6 +1010,9 @@ sub nextStream
     $status == 1
         or return $status ;
 
+    *$self->{Pending} = ''
+        if $self !~ /IO::Uncompress::RawInflate/ && ! *$self->{MultiStream};
+
     *$self->{TotalInflatedBytesRead} = 0 ;
     *$self->{LineNo} = $. = 0;
 
